---
description: Streams `metric` events to AWS CloudWatch Metrics via the `PutMetricData` API endpoint.
---

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     scripts/generate/templates/docs/usage/configuration/sinks/aws_cloudwatch_metrics.md.erb
-->

# aws_cloudwatch_metrics sink

![][assets.aws_cloudwatch_metrics_sink]

{% hint style="warning" %}
The `aws_cloudwatch_metrics` sink is in beta. Please see the current
[enhancements][urls.aws_cloudwatch_metrics_sink_enhancements] and
[bugs][urls.aws_cloudwatch_metrics_sink_bugs] for known issues.
We kindly ask that you [add any missing issues][urls.new_aws_cloudwatch_metrics_sink_issue]
as it will help shape the roadmap of this component.
{% endhint %}

The `aws_cloudwatch_metrics` sink [streams](#streaming) [`metric`][docs.data-model.metric] events to [AWS CloudWatch Metrics][urls.aws_cw_metrics] via the [`PutMetricData` API endpoint](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_PutMetricData.html).

## Config File

{% code-tabs %}
{% code-tabs-item title="vector.toml (simple)" %}
```coffeescript
[sinks.my_sink_id]
  type = "aws_cloudwatch_metrics" # must be: "aws_cloudwatch_metrics"
  inputs = ["my-source-id"]
  namespace = "service"
  region = "us-east-1"

  # For a complete list of options see the "advanced" tab above.
```
{% endcode-tabs-item %}
{% code-tabs-item title="vector.toml (advanced)" %}
```coffeescript
[sinks.aws_cloudwatch_metrics_sink]
  # The component type
  # 
  # * required
  # * no default
  # * must be: "aws_cloudwatch_metrics"
  type = "aws_cloudwatch_metrics"

  # A list of upstream source or transform IDs. See Config Composition for more
  # info.
  # 
  # * required
  # * no default
  inputs = ["my-source-id"]

  # A namespace that will isolate different metrics from each other.
  # 
  # * required
  # * no default
  namespace = "service"

  # The AWS region of the target CloudWatch stream resides.
  # 
  # * required
  # * no default
  region = "us-east-1"

  # Custom endpoint for use with AWS-compatible services.
  # 
  # * optional
  # * no default
  endpoint = "127.0.0.0:5000"

  # Enables/disables the sink healthcheck upon start.
  # 
  # * optional
  # * default: true
  healthcheck = true
```
{% endcode-tabs-item %}
{% endcode-tabs %}

## Options

| Key  | Type  | Description |
|:-----|:-----:|:------------|
| **REQUIRED** | | |
| `type` | `string` | The component type<br />`required` `must be: "aws_cloudwatch_metrics"` |
| `inputs` | `[string]` | A list of upstream [source][docs.sources] or [transform][docs.transforms] IDs. See [Config Composition][docs.configuration#composition] for more info.<br />`required` `example: ["my-source-id"]` |
| `namespace` | `string` | A [namespace](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/cloudwatch_concepts.html#Namespace) that will isolate different metrics from each other.<br />`required` `example: "service"` |
| `region` | `string` | The [AWS region][urls.aws_cw_metrics_regions] of the target CloudWatch stream resides.<br />`required` `example: "us-east-1"` |
| **OPTIONAL** | | |
| `endpoint` | `string` | Custom endpoint for use with AWS-compatible services.<br />`no default` `example: "127.0.0.0:5000"` |
| `healthcheck` | `bool` | Enables/disables the sink healthcheck upon start. See [Health Checks](#health-checks) for more info.<br />`default: true` |

## How It Works

### Authentication

Vector checks for AWS credentials in the following order:

1. Environment variables `AWS_ACCESS_KEY_ID` and `AWS_SECRET_ACCESS_KEY`.
2. The [`credential_process` command][urls.aws_credential_process] in the AWS config file. (usually located at `~/.aws/config`)
3. The [AWS credentials file][urls.aws_credentials_file]. (usually located at `~/.aws/credentials`)
4. The [IAM instance profile][urls.iam_instance_profile]. (will only work if running on an EC2 instance with an instance profile/role)

If credentials are not found the [healtcheck](#healthchecks) will fail and an
error will be [logged][docs.monitoring#logs].

#### Obtaining an access key

In general, we recommend using instance profiles/roles whenever possible. In
cases where this is not possible you can generate an AWS access key for any user
within your AWS account. AWS provides a [detailed guide][urls.aws_access_keys] on
how to do this.

### Delivery Guarantee

This component offers an [**at least once** delivery guarantee][docs.guarantees#at-least-once-delivery]
if your [pipeline is configured to achieve this][docs.guarantees#at-least-once-delivery].

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the [Environment Variables][docs.configuration#environment-variables]
section.

### Health Checks

Health checks ensure that the downstream service is accessible and ready to
accept data. This check is performed upon sink initialization.

If the health check fails an error will be logged and Vector will proceed to
start. If you'd like to exit immediately upon health check failure, you can
pass the `--require-healthy` flag:

```bash
vector --config /etc/vector/vector.toml --require-healthy
```

And finally, if you'd like to disable health checks entirely for this sink
you can set the `healthcheck` option to `false`.

### Metric Types

CloudWatch Metrics types are organized not by their semantics, but by storage properties:
- Statistic Sets
- Data Points

In Vector only the latter is used to allow lossless statistics calculations on CloudWatch side.

The following matrix outlines how Vector metric types are mapped into CloudWatch metrics types.

| Vector Metrics | CloudWatch Metrics |
|----------------|--------------------|
| Counter        | Data Point         |
| Gauge          | Data Point         |
| Gauge Delta [1]| Data Point         |
| Histogram      | Data Point         |
| Set            | N/A                |

1. Gauge values are persisted between flushes. On Vector start up each gauge is assumed to have
zero (0.0) value, that can be updated explicitly by the consequent absolute (not delta) gauge
observation, or by delta increments/decrements. Delta gauges are considered an advanced feature
useful in distributed setting, however it should be used with care.

### Streaming

The `aws_cloudwatch_metrics` sink streams data on a real-time
event-by-event basis. It does not batch data.

## Troubleshooting

The best place to start with troubleshooting is to check the
[Vector logs][docs.monitoring#logs]. This is typically located at
`/var/log/vector.log`, then proceed to follow the
[Troubleshooting Guide][docs.troubleshooting].

If the [Troubleshooting Guide][docs.troubleshooting] does not resolve your
issue, please:

1. Check for any [open `aws_cloudwatch_metrics_sink` issues][urls.aws_cloudwatch_metrics_sink_issues].
2. If encountered a bug, please [file a bug report][urls.new_aws_cloudwatch_metrics_sink_bug].
3. If encountered a missing feature, please [file a feature request][urls.new_aws_cloudwatch_metrics_sink_enhancement].
4. If you need help, [join our chat/forum community][urls.vector_chat]. You can post a question and search previous questions.

## Resources

* [**Issues**][urls.aws_cloudwatch_metrics_sink_issues] - [enhancements][urls.aws_cloudwatch_metrics_sink_enhancements] - [bugs][urls.aws_cloudwatch_metrics_sink_bugs]
* [**Source code**][urls.aws_cloudwatch_metrics_sink_source]
* [**Service Limits**][urls.aws_cw_metrics_service_limits]


[assets.aws_cloudwatch_metrics_sink]: ../../../assets/aws_cloudwatch_metrics-sink.svg
[docs.configuration#composition]: ../../../usage/configuration#composition
[docs.configuration#environment-variables]: ../../../usage/configuration#environment-variables
[docs.data-model.metric]: ../../../about/data-model/metric.md
[docs.guarantees#at-least-once-delivery]: ../../../about/guarantees.md#at-least-once-delivery
[docs.monitoring#logs]: ../../../usage/administration/monitoring.md#logs
[docs.sources]: ../../../usage/configuration/sources
[docs.transforms]: ../../../usage/configuration/transforms
[docs.troubleshooting]: ../../../usage/guides/troubleshooting.md
[urls.aws_access_keys]: https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_access-keys.html
[urls.aws_cloudwatch_metrics_sink_bugs]: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22sink%3A+aws_cloudwatch_metrics%22+label%3A%22Type%3A+bug%22
[urls.aws_cloudwatch_metrics_sink_enhancements]: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22sink%3A+aws_cloudwatch_metrics%22+label%3A%22Type%3A+enhancement%22
[urls.aws_cloudwatch_metrics_sink_issues]: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22sink%3A+aws_cloudwatch_metrics%22
[urls.aws_cloudwatch_metrics_sink_source]: https://github.com/timberio/vector/tree/master/src/sinks/aws_cloudwatch_metrics.rs
[urls.aws_credential_process]: https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-sourcing-external.html
[urls.aws_credentials_file]: https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-files.html
[urls.aws_cw_metrics]: https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/working_with_metrics.html
[urls.aws_cw_metrics_regions]: https://docs.aws.amazon.com/general/latest/gr/rande.html#cw_region
[urls.aws_cw_metrics_service_limits]: https://docs.aws.amazon.com/en_pv/AmazonCloudWatch/latest/monitoring/cloudwatch_limits.html
[urls.iam_instance_profile]: https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use_switch-role-ec2_instance-profiles.html
[urls.new_aws_cloudwatch_metrics_sink_bug]: https://github.com/timberio/vector/issues/new?labels=sink%3A+aws_cloudwatch_metrics&labels=Type%3A+bug
[urls.new_aws_cloudwatch_metrics_sink_enhancement]: https://github.com/timberio/vector/issues/new?labels=sink%3A+aws_cloudwatch_metrics&labels=Type%3A+enhancement
[urls.new_aws_cloudwatch_metrics_sink_issue]: https://github.com/timberio/vector/issues/new?labels=sink%3A+aws_cloudwatch_metrics
[urls.vector_chat]: https://chat.vector.dev
