---
description: Exposes `metric` events to Prometheus metrics service.
---

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     scripts/generate/templates/docs/usage/configuration/sinks/prometheus.md.erb
-->

# prometheus sink

![][assets.prometheus_sink]

{% hint style="warning" %}
The `prometheus` sink is in beta. Please see the current
[enhancements][urls.prometheus_sink_enhancements] and
[bugs][urls.prometheus_sink_bugs] for known issues.
We kindly ask that you [add any missing issues][urls.new_prometheus_sink_issue]
as it will help shape the roadmap of this component.
{% endhint %}

The `prometheus` sink [exposes](#exposing-and-scraping) [`metric`][docs.data-model.metric] events to [Prometheus][urls.prometheus] metrics service.

## Config File

{% code-tabs %}
{% code-tabs-item title="vector.toml (simple)" %}
```coffeescript
[sinks.my_sink_id]
  type = "prometheus" # must be: "prometheus"
  inputs = ["my-source-id"]
  address = "0.0.0.0:9598"
  namespace = "service"

  # For a complete list of options see the "advanced" tab above.
```
{% endcode-tabs-item %}
{% code-tabs-item title="vector.toml (advanced)" %}
```coffeescript
[sinks.prometheus_sink]
  # The component type
  # 
  # * required
  # * no default
  # * must be: "prometheus"
  type = "prometheus"

  # A list of upstream source or transform IDs. See Config Composition for more
  # info.
  # 
  # * required
  # * no default
  inputs = ["my-source-id"]

  # The address to expose for scraping.
  # 
  # * required
  # * no default
  address = "0.0.0.0:9598"

  # A prefix that will be added to all metric names.
  # It should follow Prometheus naming conventions.
  # 
  # * required
  # * no default
  namespace = "service"

  # Default buckets to use for histogram metrics.
  # 
  # * optional
  # * default: [0.005, 0.01, 0.025, 0.05, 0.1, 0.25, 0.5, 1.0, 2.5, 5.0, 10.0]
  # * unit: seconds
  buckets = [0.005, 0.01, 0.025, 0.05, 0.1, 0.25, 0.5, 1.0, 2.5, 5.0, 10.0]

  # Enables/disables the sink healthcheck upon start.
  # 
  # * optional
  # * default: true
  healthcheck = true
```
{% endcode-tabs-item %}
{% endcode-tabs %}

## Examples

{% tabs %}
{% tab title="Histograms" %}
This example demonstrates how Vector's internal [`histogram` metric \
type][docs.data-model.metric#histograms] is exposed via Prometheus' [text-based \
exposition format][urls.prometheus_text_based_exposition_format].

For example, given the following internal Vector histograms:

```javascript
[
  {
    "histogram": {
      "name": "response_time_s",
      "val": 0.243
    }
  },
  {
    "histogram": {
      "name": "response_time_s",
      "val": 0.546
    }
  }
]
````

The `prometheus` sink will expose this data in Prometheus'
[text-based exposition format][urls.prometheus_text_based_exposition_format]:

```text
# HELP response_time_s response_time_s
# TYPE response_time_s histogram
response_time_s_bucket{le="0.005"} 0
response_time_s_bucket{le="0.01"} 1
response_time_s_bucket{le="0.025"} 0
response_time_s_bucket{le="0.05"} 1
response_time_s_bucket{le="0.1"} 0
response_time_s_bucket{le="0.25"} 0
response_time_s_bucket{le="0.5"} 0
response_time_s_bucket{le="1.0"} 0
response_time_s_bucket{le="2.5"} 0
response_time_s_bucket{le="5.0"} 0
response_time_s_bucket{le="10.0"} 0
response_time_s_bucket{le="+Inf"} 0
response_time_s_sum 0.789
response_time_s_count 2
```

Note, the buckets used are those defined by the `buckets` option, and the
buckets above reflect the default buckets.

{% hint style="warning" %}
It's important that your metric units align with your bucket units. The default
buckets are in seconds and any metric values passed should also be in seconds.
If your metrics are not in seconds you can override the buckets to reflect
your units.
{% endhint %}
{% endtab %}
{% tab title="Counters" %}
This example demonstrates how Vector's internal [`counter` metric \
type][docs.data-model.metric#counters] is exposed via Prometheus' [text-based \
exposition format][urls.prometheus_text_based_exposition_format].

For example, given the following internal Vector gauges:

```javascript
[
  {
    "counter": {
      "name": "logins",
      "val": 1
    }
  },
  {
    "counter": {
      "name": "logins",
      "val": 3
    }
  }
]
````

The `prometheus` sink will expose this data in Prometheus'
[text-based exposition format][urls.prometheus_text_based_exposition_format]:

```text
# HELP logins logins
# TYPE logins counter
logins 4
```

Notice that Vector aggregates the metric and exposes the final value.
{% endtab %}
{% tab title="Gauges" %}
This example demonstrates how Vector's internal [`gauge` metric \
type][docs.data-model.metric#gauges] is exposed via Prometheus' [text-based \
exposition format][urls.prometheus_text_based_exposition_format].

For example, given the following internal Vector gauges:

```javascript
[
  {
    "gauge": {
      "name": "memory_rss",
      "val": 250,
      "direction": "plus"
    }
  },
  {
    "gauge": {
      "name": "memory_rss",
      "val": 25
      "direction": "minus"
    }
  }
]
````

The `prometheus` sink will expose this data in Prometheus'
[text-based exposition format][urls.prometheus_text_based_exposition_format]:

```text
# HELP memory_rss memory_rss
# TYPE memory_rss gauge
memory_rss 225
```

Notice that Vector aggregates the metric and exposes the final value.
{% endtab %}
{% endtabs %}

## How It Works

### Buffers

Due to the nature of Prometheus' pull model design the `prometheus`
sink does not utilize a buffer. You can read more about this in the [in-memory \
aggregation](#in-memory-aggregation) section.

### Delivery Guarantee

Due to the nature of this component, it offers a
[**best effort** delivery guarantee][docs.guarantees#best-effort-delivery].

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the [Environment Variables][docs.configuration#environment-variables]
section.

### Exposing & Scraping

The `prometheus` sink exposes data for scraping.
The `address` option determines the address and port the data is made available
on. You'll need to configure your networking so that the configured port is
accessible by the downstream service doing the scraping.

### High Cardinality Names

High cardinality metric names and labels are [discouraged by \
Prometheus][urls.prometheus_high_cardinality] and you should consider alternative
strategies to reduce the cardinality as this can provide performance and
operation problems. In general, high cardinality analysis should be left logs
and storages designed for this use case (not Promtheus).

### Histogram Buckets

Choosing the appropriate buckets for Prometheus histgorams is a complicated
point of discussion. The [Histograms and Summaries Prometheus \
guide][urls.prometheus_histograms_guide] provides a good overview of histograms,
buckets, summaries, and how you should think about configuring them. The buckets
you choose should align with your known range and distribution of values as
well as how you plan to report on them. The aforementioned guide provides
examples on how you should align them.

#### Default buckets

The `buckets` option defines the global default buckets for histograms:

```coffeescript
[0.005, 0.01, 0.025, 0.05, 0.1, 0.25, 0.5, 1.0, 2.5, 5.0, 10.0]
```

These defaults are tailored to broadly measure the response time (in seconds)
of a network service. Most likely, however, you will be required to define
buckets customized to your use case.

{% hint style="warning" %}
Note: These values are in `seconds`, therefore,
your metric values should also be in `seconds`.
If this is not the case you should adjust your metric or buckets to coincide.
{% endhint %}

### In-Memory Aggregation

Like other Prometheus instances, the `prometheus` sink aggregates
metrics in memory which keeps the memory footprint to a minimum if Prometheus
fails to scrape the Vector instance over an extended period of time. The
downside is that data will be lost if Vector is restarted. This is by design of
Prometheus' pull model approach, but is worth noting if restart Vector
frequently.

### Metric Definitions

By default, Vector will use the original metric names and labels set upon
creation. For most cases this makes Vector low friction, allowing you to define
the `prometheus` sink without tedious metrics definitions. You can
see examples of this in the [examples section](#examples).

### Metric Types

As described in the [metric data model][docs.data-model.metric] page, Vector offers
a variety of metric types. Their support, as as well as their mappings, are
described below:

| Vector Metric Type                               | Prometheus Metric Type               |
|:-------------------------------------------------|:-------------------------------------|
| [`counter`][docs.data-model.metric#counters]     | ['counter'][urls.prometheus_counter] |
| [`gauge`][docs.data-model.metric#gauges]         | ['gauge'][urls.prometheus_gauge]     |
| [`histogram`][docs.data-model.metric#histograms] | ['histogram'][urls.prometheus_gauge] |
| [`set`][docs.data-model.metric#sets]             | ⚠️ not supported                     |
| -                                                | ['summary'][urls.prometheus_summary] |

#### Sets

Prometheus does not have a [`set`][docs.data-model.metric#sets] type. Sets are
generally specific to [Statsd][urls.statsd_set], and if a set is received in the
`prometheus` sink it will be dropped, and a rate limited warning
level log will be emitted.

#### Summaries

Summaries are a Prometheus specific type and Vector does not default to them
by default. [issue #710][urls.issue_710] addresses the ability to define metrics,
including the ability change their types (such as changing them to `summary`
types).

## Troubleshooting

The best place to start with troubleshooting is to check the
[Vector logs][docs.monitoring#logs]. This is typically located at
`/var/log/vector.log`, then proceed to follow the
[Troubleshooting Guide][docs.troubleshooting].

If the [Troubleshooting Guide][docs.troubleshooting] does not resolve your
issue, please:

1. Check for any [open `prometheus_sink` issues][urls.prometheus_sink_issues].
2. If encountered a bug, please [file a bug report][urls.new_prometheus_sink_bug].
3. If encountered a missing feature, please [file a feature request][urls.new_prometheus_sink_enhancement].
4. If you need help, [join our chat/forum community][urls.vector_chat]. You can post a question and search previous questions.

### OOM Errors

If you experience out of memory (OOM) errors it's likely you're using extremely
[high cardinality](#high-cardinality) metric names or labels. This is
[discouraged by Prometheus][urls.prometheus_high_cardinality] and you should
consider alternative strategies to reduce the cardinality. Such as leveraging
logs for high cardinality analysis. [Issue #387][urls.issue_387] discusses the
ability to provide safeguards around this. We encourage you to add to that
discussion with your use case if you find this to be a problem.

## Resources

* [**Issues**][urls.prometheus_sink_issues] - [enhancements][urls.prometheus_sink_enhancements] - [bugs][urls.prometheus_sink_bugs]
* [**Source code**][urls.prometheus_sink_source]


[assets.prometheus_sink]: ../../../assets/prometheus-sink.svg
[docs.configuration#environment-variables]: ../../../usage/configuration#environment-variables
[docs.data-model.metric#counters]: ../../../about/data-model/metric.md#counters
[docs.data-model.metric#gauges]: ../../../about/data-model/metric.md#gauges
[docs.data-model.metric#histograms]: ../../../about/data-model/metric.md#histograms
[docs.data-model.metric#sets]: ../../../about/data-model/metric.md#sets
[docs.data-model.metric]: ../../../about/data-model/metric.md
[docs.guarantees#best-effort-delivery]: ../../../about/guarantees.md#best-effort-delivery
[docs.monitoring#logs]: ../../../usage/administration/monitoring.md#logs
[docs.troubleshooting]: ../../../usage/guides/troubleshooting.md
[urls.issue_387]: https://github.com/timberio/vector/issues/387
[urls.issue_710]: https://github.com/timberio/vector/issues/710
[urls.new_prometheus_sink_bug]: https://github.com/timberio/vector/issues/new?labels=sink%3A+prometheus&labels=Type%3A+bug
[urls.new_prometheus_sink_enhancement]: https://github.com/timberio/vector/issues/new?labels=sink%3A+prometheus&labels=Type%3A+enhancement
[urls.new_prometheus_sink_issue]: https://github.com/timberio/vector/issues/new?labels=sink%3A+prometheus
[urls.prometheus]: https://prometheus.io/
[urls.prometheus_counter]: https://prometheus.io/docs/concepts/metric_types/#counter
[urls.prometheus_gauge]: https://prometheus.io/docs/concepts/metric_types/#gauge
[urls.prometheus_high_cardinality]: https://prometheus.io/docs/practices/naming/#labels
[urls.prometheus_histograms_guide]: https://prometheus.io/docs/practices/histograms/
[urls.prometheus_sink_bugs]: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22sink%3A+prometheus%22+label%3A%22Type%3A+bug%22
[urls.prometheus_sink_enhancements]: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22sink%3A+prometheus%22+label%3A%22Type%3A+enhancement%22
[urls.prometheus_sink_issues]: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22sink%3A+prometheus%22
[urls.prometheus_sink_source]: https://github.com/timberio/vector/tree/master/src/sinks/prometheus.rs
[urls.prometheus_summary]: https://prometheus.io/docs/concepts/metric_types/#summary
[urls.prometheus_text_based_exposition_format]: https://github.com/prometheus/docs/blob/master/content/docs/instrumenting/exposition_formats.md#text-based-format
[urls.statsd_set]: https://github.com/statsd/statsd/blob/master/docs/metric_types.md#sets
[urls.vector_chat]: https://chat.vector.dev
