---
description: Accepts `log` events and allows you to add one or more log fields.
---

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     scripts/generate/templates/docs/usage/configuration/transforms/add_fields.md.erb
-->

# add_fields transform

![][assets.add_fields_transform]


The `add_fields` transform accepts [`log`][docs.data-model.log] events and allows you to add one or more log fields.

## Config File

{% code-tabs %}
{% code-tabs-item title="vector.toml (simple)" %}
```coffeescript
[transforms.my_transform_id]
  # REQUIRED - General
  type = "add_fields" # must be: "add_fields"
  inputs = ["my-source-id"]
  
  # REQUIRED - Fields
  [transforms.my_transform_id.fields]
    my_string_field = "string value"
    my_env_var_field = "${ENV_VAR}"
    my_int_field = 1
    my_float_field = 1.2
    my_bool_field = true
    my_timestamp_field = 1979-05-27T00:32:00Z
    my_nested_fields = {key1 = "value1", key2 = "value2"}
    my_list = ["first", "second", "third"]

  # For a complete list of options see the "advanced" tab above.
```
{% endcode-tabs-item %}
{% code-tabs-item title="vector.toml (advanced)" %}
```coffeescript
[transforms.add_fields_transform]
  #
  # General
  #

  # The component type
  # 
  # * required
  # * no default
  # * must be: "add_fields"
  type = "add_fields"

  # A list of upstream source or transform IDs. See Config Composition for more
  # info.
  # 
  # * required
  # * no default
  inputs = ["my-source-id"]

  #
  # Fields
  #

  [transforms.add_fields_transform.fields]
    # A key/value pair representing the new log fields to be added. Accepts all
    # supported types. Use `.` for adding nested fields.
    # 
    # * required
    # * no default
    my_string_field = "string value"
    my_env_var_field = "${ENV_VAR}"
    my_int_field = 1
    my_float_field = 1.2
    my_bool_field = true
    my_timestamp_field = 1979-05-27T00:32:00Z
    my_nested_fields = {key1 = "value1", key2 = "value2"}
    my_list = ["first", "second", "third"]
```
{% endcode-tabs-item %}
{% endcode-tabs %}

## Examples

Given the following configuration:

{% code-tabs %}
{% code-tabs-item title="vector.toml" %}
```coffeescript
[transforms.my_transform]
  type = "add_fields"
  inputs = [...]

  [transforms.my_transform.fields]
    field1 = "string value"
    field2 = 1
    field3 = 2.0
    field4 = true
    field5 = 2019-05-27T07:32:00Z
    field6 = ["item 1", "item 2"]
    field7.nested = "nested value",
    field8 = "#{HOSTNAME}"
```
{% endcode-tabs-item %}
{% endcode-tabs %}

A [`log` event][docs.data-model.log] will be emitted with the following structure:

{% code-tabs %}
{% code-tabs-item title="log" %}
```javascript
{
  // ... existing fields
  "field1": "string value",
  "field2": 1,
  "field3": 2.0,
  "field4": true,
  "field5": <timestamp:2019-05-27T07:32:00Z>,
  "field6.0": "item1",
  "field6.1": "item2",
  "field7.nested": "nested value",
  "field8": "my.hostname.com"
}
```
{% endcode-tabs-item %}
{% endcode-tabs %}

While unrealistic, this example demonstrates the various accepted
[types][docs.configuration#value-types] and how they're repsented in Vector's
internal [log structure][docs.data-model.log].

## How It Works

### Arrays

The `add_fields` transform will support [TOML arrays][urls.toml_array]. Keep in
mind that the values must be simple type (not tables), and each value must the
same type. You cannot mix types:

```coffeescript
[transforms.<transform-id>]
  # ...
  
  [transforms.<transform-id>.fields]
    my_array = ["first", "second", "third"]
```

Results in:

```json
{
  "my_array.0": "first",
  "my_array.1": "second",
  "my_array.2": "third"
}
```

Learn more about how [`log` events][docs.data-model.log] are structured.

### Complex Transforming

The `add_fields` transform is designed for simple key additions. If you need
more complex transforming then we recommend using a more versatile transform
like the [`lua` transform][docs.transforms.lua].

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the [Environment Variables][docs.configuration#environment-variables]
section.

### Key Conflicts

Keys specified in this transform will replace existing keys.

### Nested Fields

The `add_fields` transform will support dotted keys or [TOML
tables][urls.toml_table]. We recommend the dotted key syntax since it is less
verbose for this usecase:

```
[transforms.<transform-id>]
  # ...
  
  [transforms.<transform-id>.fields]
    parent.child.grandchild = "my_value"
```

Results in:

```json
{
  "parent.child.grandchild": "my_value"
}
```

Learn more about how [`log` events][docs.data-model.log] are structured.

### Removing Fields

See the [`remove_fields` transform][docs.transforms.remove_fields].

### Special Characters

Aside from the [special characters][docs.data-model.log#special-characters]
listed in the [Data Model][docs.data-model] doc, Vector does not restrict the
characters allowed in keys. You can wrap key names in `" "` quote to preserve
spaces and use `\` to escape quotes.

### Types

All supported [configuration value types][docs.configuration#value-types] are accepted.
This includes primitivate types (`string`, `int`, `float`, `boolean`) and
special types, such as [arrays](#arrays) and [nested fields](#nested-fields).

## Troubleshooting

The best place to start with troubleshooting is to check the
[Vector logs][docs.monitoring#logs]. This is typically located at
`/var/log/vector.log`, then proceed to follow the
[Troubleshooting Guide][docs.troubleshooting].

If the [Troubleshooting Guide][docs.troubleshooting] does not resolve your
issue, please:

1. Check for any [open `add_fields_transform` issues][urls.add_fields_transform_issues].
2. If encountered a bug, please [file a bug report][urls.new_add_fields_transform_bug].
3. If encountered a missing feature, please [file a feature request][urls.new_add_fields_transform_enhancement].
4. If you need help, [join our chat/forum community][urls.vector_chat]. You can post a question and search previous questions.


### Alternatives

Finally, consider the following alternatives:

* [`lua` transform][docs.transforms.lua]
* [`remove_fields` transform][docs.transforms.remove_fields]

## Resources

* [**Issues**][urls.add_fields_transform_issues] - [enhancements][urls.add_fields_transform_enhancements] - [bugs][urls.add_fields_transform_bugs]
* [**Source code**][urls.add_fields_transform_source]


[assets.add_fields_transform]: ../../../assets/add_fields-transform.svg
[docs.configuration#environment-variables]: ../../../usage/configuration#environment-variables
[docs.configuration#value-types]: ../../../usage/configuration#value-types
[docs.data-model.log#special-characters]: ../../../about/data-model/log.md#special-characters
[docs.data-model.log]: ../../../about/data-model/log.md
[docs.data-model]: ../../../about/data-model
[docs.monitoring#logs]: ../../../usage/administration/monitoring.md#logs
[docs.transforms.lua]: ../../../usage/configuration/transforms/lua.md
[docs.transforms.remove_fields]: ../../../usage/configuration/transforms/remove_fields.md
[docs.troubleshooting]: ../../../usage/guides/troubleshooting.md
[urls.add_fields_transform_bugs]: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+add_fields%22+label%3A%22Type%3A+bug%22
[urls.add_fields_transform_enhancements]: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+add_fields%22+label%3A%22Type%3A+enhancement%22
[urls.add_fields_transform_issues]: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+add_fields%22
[urls.add_fields_transform_source]: https://github.com/timberio/vector/tree/master/src/transforms/add_fields.rs
[urls.new_add_fields_transform_bug]: https://github.com/timberio/vector/issues/new?labels=transform%3A+add_fields&labels=Type%3A+bug
[urls.new_add_fields_transform_enhancement]: https://github.com/timberio/vector/issues/new?labels=transform%3A+add_fields&labels=Type%3A+enhancement
[urls.toml_array]: https://github.com/toml-lang/toml#array
[urls.toml_table]: https://github.com/toml-lang/toml#table
[urls.vector_chat]: https://chat.vector.dev
