---
description: Accepts `log` events and allows you to parse a log field value with Grok.
---

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     scripts/generate/templates/docs/usage/configuration/transforms/grok_parser.md.erb
-->

# grok_parser transform

![][assets.grok_parser_transform]


The `grok_parser` transform accepts [`log`][docs.data-model.log] events and allows you to parse a log field value with [Grok][urls.grok].

## Config File

{% code-tabs %}
{% code-tabs-item title="vector.toml (simple)" %}
```coffeescript
[transforms.my_transform_id]
  type = "grok_parser" # must be: "grok_parser"
  inputs = ["my-source-id"]
  pattern = "%{TIMESTAMP_ISO8601:timestamp} %{LOGLEVEL:level} %{GREEDYDATA:message}"

  # For a complete list of options see the "advanced" tab above.
```
{% endcode-tabs-item %}
{% code-tabs-item title="vector.toml (advanced)" %}
```coffeescript
[transforms.grok_parser_transform]
  #
  # General
  #

  # The component type
  # 
  # * required
  # * no default
  # * must be: "grok_parser"
  type = "grok_parser"

  # A list of upstream source or transform IDs. See Config Composition for more
  # info.
  # 
  # * required
  # * no default
  inputs = ["my-source-id"]

  # The Grok pattern
  # 
  # * required
  # * no default
  pattern = "%{TIMESTAMP_ISO8601:timestamp} %{LOGLEVEL:level} %{GREEDYDATA:message}"

  # If `true` will drop the specified `field` after parsing.
  # 
  # * optional
  # * default: true
  drop_field = true

  # The log field to execute the `pattern` against. Must be a `string` value.
  # 
  # * optional
  # * default: "message"
  field = "message"

  #
  # Types
  #

  [transforms.grok_parser_transform.types]
    # A definition of mapped log field types. They key is the log field name and
    # the value is the type. `strftime` specifiers are supported for the
    # `timestamp` type.
    # 
    # * required
    # * no default
    # * enum: "string", "int", "float", "bool", and "timestamp|strftime"
    status = "int"
    duration = "float"
    success = "bool"
    timestamp = "timestamp|%s"
    timestamp = "timestamp|%+"
    timestamp = "timestamp|%F"
    timestamp = "timestamp|%a %b %e %T %Y"
```
{% endcode-tabs-item %}
{% endcode-tabs %}

## How It Works

### Available Patterns

Vector uses the Rust [`grok` library][urls.rust_grok_library]. All patterns
[listed here][urls.grok_patterns] are supported. It is recommended to use
maintained patterns when possible since they can be improved over time by
the community.

### Debugging

We recommend the [Grok debugger][urls.grok_debugger] for Grok testing.

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the [Environment Variables][docs.configuration#environment-variables]
section.

### Performance

Grok is approximately 50% slower than the [`regex_parser` transform][docs.transforms.regex_parser].
We plan to add a [performance test][docs.performance] for this in the future.
While this is still plenty fast for most use cases we recommend using the
[`regex_parser` transform][docs.transforms.regex_parser] if you are experiencing
performance issues.

### Types

By default, extracted (parsed) fields all contain `string` values. You can
coerce these values into types via the `types` table as shown in the
[Config File](#config-file) example above. For example:

```coffeescript
[transforms.my_transform_id]
  # ...

  # OPTIONAL - Types
  [transforms.my_transform_id.types]
    status = "int"
    duration = "float"
    success = "bool"
    timestamp = "timestamp|%s"
    timestamp = "timestamp|%+"
    timestamp = "timestamp|%F"
    timestamp = "timestamp|%a %b %e %T %Y"
```

The available types are:

| Type        | Desription                                                                                                          |
|:------------|:--------------------------------------------------------------------------------------------------------------------|
| `bool`      | Coerces to a `true`/`false` boolean. The `1`/`0` and `t`/`f` values are also coerced.                               |
| `float`     | Coerce to 64 bit floats.                                                                                            |
| `int`       | Coerce to a 64 bit integer.                                                                                         |
| `string`    | Coerces to a string. Generally not necessary since values are extracted as strings.                                 |
| `timestamp` | Coerces to a Vector timestamp. [`strftime` specificiers][urls.strftime_specifiers] must be used to parse the string. |

## Troubleshooting

The best place to start with troubleshooting is to check the
[Vector logs][docs.monitoring#logs]. This is typically located at
`/var/log/vector.log`, then proceed to follow the
[Troubleshooting Guide][docs.troubleshooting].

If the [Troubleshooting Guide][docs.troubleshooting] does not resolve your
issue, please:

1. Check for any [open `grok_parser_transform` issues][urls.grok_parser_transform_issues].
2. If encountered a bug, please [file a bug report][urls.new_grok_parser_transform_bug].
3. If encountered a missing feature, please [file a feature request][urls.new_grok_parser_transform_enhancement].
4. If you need help, [join our chat/forum community][urls.vector_chat]. You can post a question and search previous questions.


### Alternatives

Finally, consider the following alternatives:

* [`lua` transform][docs.transforms.lua]
* [`regex_parser` transform][docs.transforms.regex_parser]
* [`split` transform][docs.transforms.split]
* [`tokenizer` transform][docs.transforms.tokenizer]

## Resources

* [**Issues**][urls.grok_parser_transform_issues] - [enhancements][urls.grok_parser_transform_enhancements] - [bugs][urls.grok_parser_transform_bugs]
* [**Source code**][urls.grok_parser_transform_source]
* [**Grok Debugger**][urls.grok_debugger]
* [**Grok Patterns**][urls.grok_patterns]


[assets.grok_parser_transform]: ../../../assets/grok_parser-transform.svg
[docs.configuration#environment-variables]: ../../../usage/configuration#environment-variables
[docs.data-model.log]: ../../../about/data-model/log.md
[docs.monitoring#logs]: ../../../usage/administration/monitoring.md#logs
[docs.performance]: ../../../performance.md
[docs.transforms.lua]: ../../../usage/configuration/transforms/lua.md
[docs.transforms.regex_parser]: ../../../usage/configuration/transforms/regex_parser.md
[docs.transforms.split]: ../../../usage/configuration/transforms/split.md
[docs.transforms.tokenizer]: ../../../usage/configuration/transforms/tokenizer.md
[docs.troubleshooting]: ../../../usage/guides/troubleshooting.md
[urls.grok]: http://grokdebug.herokuapp.com/
[urls.grok_debugger]: http://grokdebug.herokuapp.com/
[urls.grok_parser_transform_bugs]: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+grok_parser%22+label%3A%22Type%3A+bug%22
[urls.grok_parser_transform_enhancements]: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+grok_parser%22+label%3A%22Type%3A+enhancement%22
[urls.grok_parser_transform_issues]: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+grok_parser%22
[urls.grok_parser_transform_source]: https://github.com/timberio/vector/tree/master/src/transforms/grok_parser.rs
[urls.grok_patterns]: https://github.com/daschl/grok/tree/master/patterns
[urls.new_grok_parser_transform_bug]: https://github.com/timberio/vector/issues/new?labels=transform%3A+grok_parser&labels=Type%3A+bug
[urls.new_grok_parser_transform_enhancement]: https://github.com/timberio/vector/issues/new?labels=transform%3A+grok_parser&labels=Type%3A+enhancement
[urls.rust_grok_library]: https://github.com/daschl/grok
[urls.strftime_specifiers]: https://docs.rs/chrono/0.3.1/chrono/format/strftime/index.html
[urls.vector_chat]: https://chat.vector.dev
